@@ -10,7 +10,7 @@ Function.prototype.inherits = function(parentCtor) {
   this.prototype = new tempCtor();
 }  
 
-//@line 36 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/application.js"
+//@line 36 "/browser/components/safebrowsing/content/application.js"
 
 // We instantiate this variable when we create the application.
 var gDataProvider = null;
@@ -32,7 +32,7 @@ var gDataProvider = null;
 function PROT_Application() {
   this.debugZone= "application";
 
-//@line 83 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/application.js"
+//@line 83 "/browser/components/safebrowsing/content/application.js"
   
   // expose some classes
   this.PROT_PhishingWarden = PROT_PhishingWarden;
@@ -123,7 +123,7 @@ PROT_Application.prototype.QueryInterface = function(iid) {
   Components.returnCode = Components.results.NS_ERROR_NO_INTERFACE;
   return null;
 }
-//@line 37 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/globalstore.js"
+//@line 37 "/browser/components/safebrowsing/content/globalstore.js"
 
 
 // A class that encapsulates data provider specific values.  The
@@ -145,9 +145,9 @@ PROT_Application.prototype.QueryInterface = function(iid) {
 const kDataProviderIdPref = 'browser.safebrowsing.dataProvider';
 const kProviderBasePref = 'browser.safebrowsing.provider.';
 
-//@line 61 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/globalstore.js"
+//@line 61 "/browser/components/safebrowsing/content/globalstore.js"
 const MOZ_OFFICIAL_BUILD = false;
-//@line 63 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/globalstore.js"
+//@line 63 "/browser/components/safebrowsing/content/globalstore.js"
 
 const MOZ_PARAM_LOCALE = /\{moz:locale\}/g;
 const MOZ_PARAM_CLIENT = /\{moz:client\}/g;
@@ -201,6 +201,8 @@ PROT_DataProvider.prototype.loadDataProviderPrefs_ = function() {
   this.reportGenericURL_ = this.getUrlPref_(basePref + "reportGenericURL");
   this.reportErrorURL_ = this.getUrlPref_(basePref + "reportErrorURL");
   this.reportPhishURL_ = this.getUrlPref_(basePref + "reportPhishURL");
+  this.reportMalwareURL_ = this.getUrlPref_(basePref + "reportMalwareURL")
+  this.reportMalwareErrorURL_ = this.getUrlPref_(basePref + "reportMalwareErrorURL")
 
   // Propagate the changes to the list-manager.
   this.updateListManager_();
@@ -308,7 +310,13 @@ PROT_DataProvider.prototype.getReportErrorURL = function() {
 PROT_DataProvider.prototype.getReportPhishURL = function() {
   return this.reportPhishURL_;
 }
-//@line 37 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/list-warden.js"
+PROT_DataProvider.prototype.getReportMalwareURL = function() {
+  return this.reportMalwareURL_;
+}
+PROT_DataProvider.prototype.getReportMalwareErrorURL = function() {
+  return this.reportMalwareErrorURL_;
+}
+//@line 37 "/browser/components/safebrowsing/content/list-warden.js"
 
 // A warden that knows how to register lists with a listmanager and keep them
 // updated if necessary.  The ListWarden also provides a simple interface to
@@ -408,7 +416,7 @@ PROT_ListWarden.prototype.registerWhiteTable = function(tableName) {
   }
   return result;
 }
-//@line 36 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/phishing-warden.js"
+//@line 36 "/browser/components/safebrowsing/content/phishing-warden.js"
 
 
 // The warden checks request to see if they are for phishy pages. It
@@ -537,7 +545,7 @@ PROT_PhishingWarden.prototype.onPhishWardenEnabledPrefChanged = function(
     this.prefs_.getPref(prefName, this.phishWardenEnabled_);
   this.maybeToggleUpdateChecking();
 }
-//@line 37 "/icecat-3.0.11-g1/browser/components/safebrowsing/content/malware-warden.js"
+//@line 37 "/browser/components/safebrowsing/content/malware-warden.js"
 
 // This warden manages updates to the malware list
 
@@ -658,7 +666,7 @@ PROT_MalwareWarden.prototype.onMalwareWardenEnabledPrefChanged = function(
     this.prefs_.getPref(prefName, this.malwareWardenEnabled_);
   this.maybeToggleUpdateChecking();
 }
-//@line 18 "/icecat-3.0.11-g1/browser/components/safebrowsing/src/nsSafebrowsingApplication.js"
+//@line 18 "/browser/components/safebrowsing/src/nsSafebrowsingApplication.js"
 
 var modScope = this;
 function Init() {
